@@ -34,8 +34,8 @@
 #include "fxjs/fx_date_helpers.h"
 #include "fxjs/js_define.h"
 #include "fxjs/js_resources.h"
-#include "third_party/base/optional.h"
-#include "third_party/base/stl_util.h"
+#include "base/optional.h"
+#include "base/stl_util.h"
 
 // static
 const JSMethodSpec CJS_PublicMethods::GlobalFunctionSpecs[] = {
